const { execSync } = require("child_process");
const path = require("path");
const fs = require("fs");

// Get the user's project directory
const userProjectDir = path.resolve(process.cwd());

// ESLint config file (if any)
const eslintConfigPath = path.join(userProjectDir, ".eslintrc.js");

// Create a default ESLint configuration if none exists
if (!fs.existsSync(eslintConfigPath)) {
  fs.writeFileSync(
    eslintConfigPath,
    `
module.exports = {
  extends: [],
  plugins: ["react-coding-standards"],
  rules: {
    "react-coding-standards/enforce-function-length": "warn",
    "react-coding-standards/enforce-redux-action-naming": "warn",
    "react-coding-standards/enforce-useeffect-dependencies": "warn",
  },
};
    `,
    "utf-8"
  );
  console.log("Default ESLint configuration created.");
} else {
  console.log("Using existing ESLint configuration.");
}

// Run ESLint using Node.js child process
try {
  console.log("Running ESLint with react-coding-standards...");
  execSync(`npx eslint ${userProjectDir} --ext .js,.jsx,.ts,.tsx`, {
    stdio: "inherit",
  });
  console.log("Linting completed successfully!");
} catch (error) {
  console.error("Error running ESLint:", error.message);
  process.exit(1);
}
